@@ -6,4 +6,11 @@ class LogisticRegression(SklearnClassifier, SklearnImplementation):
     """
     sklearn.linear_model.LogisticRegression wrapper
     """
-    pass
\ No newline at end of file
+    def hyperparameters_grid(self, X=None):
+        """
+
+        """
+        return {
+            'C': [0.01, 0.1, 1],
+            'max_iter': [1e3, 1e4, 1e5]
+        }
\ No newline at end of file
