@@ -1,4 +1,7 @@
 from eloquentarduino.ml.data.preprocessing import PrincipalFFT
 from eloquentarduino.ml.data.CheckpointFile import CheckpointFile
 from eloquentarduino.ml.data.Dataset import Dataset
+from eloquentarduino.ml.data.DatasetLoader import DatasetsLoader as DatasetLoaderClass
 from eloquentarduino.ml.data.PandasDataset import PandasDataset
+
+DatasetLoader = DatasetLoaderClass()
